package VMOMI::InvalidProfileReferenceHostReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
